==> org.robokind.api.messaging-0.8.2-sources.jar: org/robokind/api/messaging/MessageBlockingReceiver.java <==
/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.messaging;

import java.util.concurrent.TimeoutException;
import org.robokind.api.common.utils.Adapter;
import org.robokind.api.common.utils.Listener;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public interface MessageBlockingReceiver<Msg, Rec, L extends Listener<Msg>> {
    /**
     * Sets the RecordAsyncReceiver used to receive Records.
     * @param service theRecordReceiver to set
     */
    public void setRecordReceiver(RecordBlockingReceiver<Rec> service);
    /**
     * Sets the Adapter used to convert Records to Messages.
     * @param adapter  the Adapter to set
     */
    public void setAdapter(Adapter<Rec,Msg> adapter);
    
    /**
     * Initializes and connects the MessageAsyncReceiver, and begins receiving
     * Messages.
     * @throws Exception if there is an error starting
     */
    public void start() throws Exception;
    /**
     * Stops the MessageAsyncReceiver, making it unable to receive Messages.
     */
    public void stop();
    
    /**
     * Blocks while waiting for a Message.
     * @param timeout timeout length in milliseconds
     * @return Message received from a MessageSender, null if no Message 
     * received before timeout
     */
    public Msg fetchMessage(long timeout);
    
    /**
     * Removes any pending messages for this receiver.  
     * Returns the number of messages cleared.
     * @return number of messages cleared
     */
    public int clearMessages();
    
    /**
     * Adds a Listener to be notified when a Message has been received.
     * @param listener the Listener to be notified
     */
    public void addMessageListener(L listener);
    /**
     * Removes a Listener from being notified.
     * @param listener the Listener to remove
     */
    public void removeMessageListener(L listener);
}

==> org.robokind.api.messaging-0.8.4-sources.jar: org/robokind/api/messaging/MessageBlockingReceiver.java <==
/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.messaging;

import org.robokind.api.common.utils.Listener;

/**
 * Synchronous message receiver.
 * Uses a RecordBlockingReceiver to wait for a Record.
 * Uses an Adapter to adapt Records to Messages. 
 * 
 * @param <Msg> type of Message to return 
 * @author Matthew Stevenson <www.robokind.org>
 */
public interface MessageBlockingReceiver<Msg> {
    /**
     * Initializes and connects the MessageAsyncReceiver, and begins receiving
     * Messages.
     * @throws Exception if there is an error starting
     */
    public void start() throws Exception;
    /**
     * Stops the MessageAsyncReceiver, making it unable to receive Messages.
     */
    public void stop();
    
    /**
     * Blocks while waiting for a Message.
     * @param timeout timeout length in milliseconds
     * @return Message received from a MessageSender, null if no Message 
     * received before timeout
     */
    public Msg fetchMessage(long timeout);
    
    /**
     * Removes any pending messages for this receiver.  
     * Returns the number of messages cleared.
     * @return number of messages cleared
     */
    public int clearMessages();
    
    /**
     * Adds a Listener to be notified when a Message has been received.
     * @param listener the Listener to be notified
     */
    public void addMessageListener(Listener<Msg> listener);
    /**
     * Removes a Listener from being notified.
     * @param listener the Listener to remove
     */
    public void removeMessageListener(Listener<Msg> listener);
}
